@@ -70,7 +70,7 @@ types_converter_dict = {
             "enum": "long varchar",
             "double": "double precision",
         },
-        "default": {"current_timestamp": "now()"},
+        "default": {"current_timestamp": "now()", "'0000-00-00 00:00:00'": "null"},
     },
     "mysql:exasol": {
         "type": {
@@ -142,16 +142,37 @@ max_length_mult = {
 }
 
 python_type_dict = {
-    "ch": {"str": "Nullable(String)", "bool": "UInt8", "int": "UInt32"},
+    "ch": {
+        "str": "Nullable(String)",
+        "bool": "UInt8",
+        "int": "UInt32",
+        "float": "float",
+    },
     "pg": {},
     "mysql": {},
-    "vertica": {},
+    "vertica": {
+        "str": "long varchar(1000)",
+        "int": "bigint",
+        "bool": "boolean",
+        "float": "double precision",
+    },
     "exasol": {},
 }
 
 # types update to insert then
 update_types_dict = {
-    "ch": {"int32": "int", "int8": "bool", "str": "str", "float": "float"},
+    "ch": {
+        "str": "str",
+        "float": "float",
+        "uint8": "bool",
+        "uint16": "int",
+        "uint32": "int",
+        "uint64": "int",
+        "int8": "int",
+        "int16": "int",
+        "int32": "int",
+        "int64": "int",
+    },
     "pg": {
         "double precision": "float",
         "integer": "int",
@@ -195,6 +216,8 @@ def update_value_type(fields, item, key, db="ch", dict_replace_str={}):
         )
     if item is None:
         return item
+    if key not in item:
+        return item
     if item[key] is None:
         return item
     type = "str"
@@ -317,11 +340,12 @@ class FieldsConverterOneWay:
         :param debug: show debug text
         :param tables:  converter only for list of tables. Will process more rapid
         """
+
         self.tables = tables or []
         self.db = db
         self.debug = debug
         self.sql_credentials = sql_credentials
-        cred = self.sql_credentials[self.db]
+        self.cred = self.sql_credentials[self.db]
 
         if self.db not in dialect_dict:
             raise ModuleNotFoundError(
@@ -333,28 +357,38 @@ class FieldsConverterOneWay:
             dialect_from = dialect_dict[self.db]
         uri_sql_alchemy = "{0}://{1}:{2}@{3}:{4}/{5}".format(
             dialect_from,
-            cred["user"],
-            cred["password"],
-            cred["host"],
-            cred["port"],
-            cred["database"],
+            self.cred["user"],
+            self.cred["password"],
+            self.cred["host"],
+            self.cred["port"],
+            self.cred["database"],
         )
 
         if "connect_args" in self.sql_credentials[self.db]:
             connect_args = self.sql_credentials[self.db]["connect_args"]
         else:
             connect_args = {}
-        engine = create_engine(uri_sql_alchemy, connect_args=connect_args)
-        self.conn = engine.connect()
+        self.engine = create_engine(uri_sql_alchemy, connect_args=connect_args)
+        self.conn = self.engine.connect()
         self.log("connecting to {} successfull".format(self.db))
-        if "schema" in cred:
-            self.schema = cred["schema"]
-            self.meta = MetaData(bind=engine, schema=self.schema)
-        else:
-            self.meta = MetaData(bind=engine)
         self.quote_char = quotes_dict[self.db]
-        if len(self.tables) > 0:
-            self.meta.reflect(only=self.tables)
+        self.init_meta()
+
+    def init_meta(self, tables=None):
+        """
+        reinit meta objects
+        :return:
+        """
+        if "schema" in self.cred:
+            self.schema = self.cred["schema"]
+            self.meta = MetaData(bind=self.engine, schema=self.schema)
+        else:
+            self.meta = MetaData(bind=self.engine)
+            self.schema = self.cred["database"]
+
+        tables = tables or self.tables
+        if len(tables) > 0:
+            self.meta.reflect(only=tables)
         else:
             self.meta.reflect()
 
@@ -381,6 +415,32 @@ class FieldsConverterOneWay:
     def __del__(self):
         self.conn.close()
 
+    def update_value_df_type(self, table_name, dataframe, db="ch", dict_replace_str={}):
+        """
+        :param fields:
+        :param dataframe:
+        :param db:
+        :param dict_replace_str:
+        :return:
+        """
+        if db not in dialect_dict:
+            raise ModuleNotFoundError(
+                "Dialect for {} type of database was'nt found, should be in list {}".format(
+                    db, list(dialect_dict.keys())
+                )
+            )
+        fields = self.get_columns(table_name)
+        for key in list(dataframe.columns):
+            type = "str"
+            for type_old in update_types_dict[db]:
+                if fields[key].lower().find(type_old) > -1:
+                    type = update_types_dict[db][type_old]
+
+            dataframe[key] = dataframe[key].astype(type)
+            if type == "str":
+                dataframe[key] = dataframe[key].replace(to_replace=dict_replace_str)
+        return dataframe
+
     def update_value_type(self, table_name, items, dict_replace_str={}):
         """
         :param dict_replace_str: replace in string dict
@@ -389,6 +449,8 @@ class FieldsConverterOneWay:
         :return:
         """
         fields = self.get_columns(table_name=table_name)
+        if len(fields) == 0:
+            raise Exception("No table {} in metadata".format(table_name))
         keys = fields.keys()
         for item in items:
             for key in keys:
@@ -459,7 +521,7 @@ class FieldsConverter:
         self.debug = debug
         self.sql_credentials = sql_credentials
 
-        cred_from = self.sql_credentials[self.from_db]
+        self.cred_from = self.sql_credentials[self.from_db]
 
         if self.from_db not in dialect_dict:
             raise ModuleNotFoundError(
@@ -472,13 +534,13 @@ class FieldsConverter:
 
         uri_sql_alchemy_from = "{0}://{1}:{2}@{3}:{4}/{5}".format(
             dialect_from,
-            cred_from["user"],
-            cred_from["password"],
-            cred_from["host"],
-            cred_from["port"],
-            cred_from["database"],
+            self.cred_from["user"],
+            self.cred_from["password"],
+            self.cred_from["host"],
+            self.cred_from["port"],
+            self.cred_from["database"],
         )
-        cred_to = self.sql_credentials[self.to_db]
+        self.cred_to = self.sql_credentials[self.to_db]
         if self.to_db not in dialect_dict:
             raise ModuleNotFoundError(
                 "Dialect for {} type of database was'nt found, should be in list {}".format(
@@ -490,43 +552,53 @@ class FieldsConverter:
 
         uri_sql_alchemy_to = "{0}://{1}:{2}@{3}:{4}/{5}".format(
             dialect_to,
-            cred_to["user"],
-            cred_to["password"],
-            cred_to["host"],
-            cred_to["port"],
-            cred_to["database"],
+            self.cred_to["user"],
+            self.cred_to["password"],
+            self.cred_to["host"],
+            self.cred_to["port"],
+            self.cred_to["database"],
         )
         self.quote_char = quotes_dict[self.to_db]
         if "connect_args" in self.sql_credentials[self.from_db]:
             connect_args = self.sql_credentials[self.from_db]["connect_args"]
         else:
             connect_args = {}
-        engine_from = create_engine(uri_sql_alchemy_from, connect_args=connect_args)
-        self.conn_from = engine_from.connect()
+        self.engine_from = create_engine(
+            uri_sql_alchemy_from, connect_args=connect_args
+        )
+        self.conn_from = self.engine_from.connect()
         self.log("connecting to {} successfull".format(self.from_db))
 
         if "connect_args" in self.sql_credentials[self.to_db]:
             connect_args = self.sql_credentials[self.to_db]["connect_args"]
         else:
             connect_args = {}
-        engine_to = create_engine(uri_sql_alchemy_to, connect_args=connect_args)
-        self.conn_to = engine_to.connect()
+        self.engine_to = create_engine(uri_sql_alchemy_to, connect_args=connect_args)
+        self.conn_to = self.engine_to.connect()
         self.log("connecting to {} successfull".format(self.to_db))
-        if "schema" in cred_from:
-            self.schema_from = cred_from["schema"]
-            self.meta_from = MetaData(bind=engine_from, schema=self.schema_from)
-        else:
-            self.meta_from = MetaData(bind=engine_from)
 
-        if "schema" in cred_to:
-            self.schema_to = cred_to["schema"]
-            self.meta_to = MetaData(bind=engine_to, schema=self.schema_to)
-        else:
-            self.meta_to = MetaData(bind=engine_to)
+    def init_meta(self, tables=None):
+        """
 
-        if len(self.tables) > 0:
-            self.meta_from.reflect(only=self.tables)
-            self.meta_to.reflect(only=self.tables)
+        :param tables:
+        :return:
+        """
+        if "schema" in self.cred_from:
+            self.schema_from = self.cred_from["schema"]
+            self.meta_from = MetaData(bind=self.engine_from, schema=self.schema_from)
+        else:
+            self.meta_from = MetaData(bind=self.engine_from)
+
+        if "schema" in self.cred_to:
+            self.schema_to = self.cred_to["schema"]
+            self.meta_to = MetaData(bind=self.engine_to, schema=self.schema_to)
+        else:
+            self.meta_to = MetaData(bind=self.engine_to)
+
+        tables = tables or self.tables
+        if len(tables) > 0:
+            self.meta_from.reflect(only=tables)
+            self.meta_to.reflect(only=tables)
         else:
             self.meta_from.reflect()
             self.meta_to.reflect()
@@ -582,8 +654,8 @@ class FieldsConverter:
             if sort_part is not None:
                 add_part = generate_sort_part_vertica(sort_part, date_field=date_field)
                 if (
-                        date_field != ""
-                        and fields[date_field].lower().find("not null") == -1
+                    date_field != ""
+                    and fields[date_field].lower().find("not null") == -1
                 ):
                     fields[date_field] += " not null"
         elif self.to_db == "exasol":
